@@ -2,7 +2,7 @@ import logging
 
 from fastapi import APIRouter
 
-from eventix.functions.tools import metrics
+from eventix.functions.metrics import Metrics
 
 log = logging.getLogger(__name__)
 
@@ -11,4 +11,4 @@ router = APIRouter(tags=["metrics"])
 
 @router.get("/metrics")
 async def metrics_get():
-    return metrics()
+    return Metrics.dict()
